Serialized Form (py4j-java 0.10.9.4 API)
Date: 2022-03-16

# Serialized Form

- ## Package py4j

  - ### Class py4j.Py4JAuthenticationException extends Py4JException implements Serializable

    serialVersionUID:
      -8121049552991789743L

  - ### Class py4j.Py4JException extends java.lang.RuntimeException implements Serializable

    serialVersionUID:
      -2457373060192300387L

  - ### Class py4j.Py4JJavaException extends Py4JException implements Serializable

    serialVersionUID:
      -8121049552991788743L

  - ### Class py4j.Py4JNetworkException extends Py4JException implements Serializable

    serialVersionUID:
      -3338931855286981212L

    - ### Serialized Fields

      - #### when

            Py4JNetworkException.ErrorTime when

- ## Package py4j.reflection

  - ### Class py4j.reflection.LRUCache extends java.util.LinkedHashMap<K,V> implements Serializable

    serialVersionUID:
      -3090703237387586885L

    - ### Serialized Fields

      - #### cacheSize

            int cacheSize